cloud

package
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 19, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Package cloud defines provider-neutral capabilities shared by Podmin consumers.

Index

Constants

This section is empty.

Variables

var ErrExists = fs.ErrExist

ErrExists identifies an object or secret that already exists.

ErrNotFound identifies a missing object to generic callers and s3lect.

var ErrPrecondition = s3lect.ErrStoragePrecondition

ErrPrecondition identifies a failed conditional object write.

Functions

This section is empty.

Types

type Bucket

type Bucket interface {
	EnsureBucket(context.Context) error
	EmptyAndDeleteBucket(context.Context) error
}

Bucket manages the object-storage container owned by a cluster.

type Client

type Client struct {
	Bucket        Bucket
	Objects       ObjectStore
	SecretStores  map[secrets.Provider]secrets.Manager
	SystemSecrets secrets.Manager
	Compute       Compute
}

Client contains provider-neutral CLI capabilities.

type Compute

type Compute interface {
	Architecture(context.Context, string) (string, error)
	SubnetCIDRs(context.Context, string, netip.Prefix, []string) (map[string]string, bool, error)
}

Compute provides the infrastructure discovery needed during setup.

type ObjectInfo

type ObjectInfo struct {
	Key      string
	Modified time.Time
}

ObjectInfo describes a listed object without its body.

type ObjectStore

type ObjectStore interface {
	Get(context.Context, string) ([]byte, string, error)
	PutStream(context.Context, string, io.Reader, int64) error
	PutIfMatch(context.Context, string, []byte, string) error
	List(context.Context, string) ([]ObjectInfo, error)
	Delete(context.Context, string) error
}

ObjectStore provides the object operations used by the CLI.

Directories

Path Synopsis
Package aws provides AWS adapters shared by Podmin's CLI and agent.
Package aws provides AWS adapters shared by Podmin's CLI and agent.

Jump to